@@ -1,3 +1,5 @@
+"""Dealer context middleware for extracting dealer information from requests."""
+
 from typing import Annotated
 from uuid import UUID
 
@@ -15,7 +17,7 @@ def get_dealer_data(
         UUID | None,
         Header(
             alias="main-dealer-id",
-            description="Unique identifier of the primary dealer associated with the request."
+            description="Unique identifier of the primary dealer associated with the request.",
         ),
     ] = None,
 ) -> DealerData:
