@@ -1,9 +1,9 @@
-"""Wrapper around :func:`json.dumps` that forces serialisation of unknown types."""
+"""Wrapper around :func:`json.dumps` that forces serialisation of unknown
+types."""
 
 import json
 from typing import Any
 
-
 __all__ = ("jsonable_encoder",)
 
 
