@@ -1,6 +1,6 @@
 """Small URL manipulation helpers."""
 
-from typing import Dict, Any
+from typing import Any, Dict
 from urllib.parse import parse_qs, urlencode, urlparse, urlunparse
 
 __all__ = ("add_query_param",)
