@@ -7,10 +7,11 @@ and health checks for both read and write connections.
 from __future__ import annotations
 
 from contextlib import asynccontextmanager, contextmanager
-from typing import AsyncGenerator, Generator, Optional, Any
+from typing import Any, AsyncGenerator, Generator, Optional
 
 from sqlalchemy import NullPool, create_engine, text
-from sqlalchemy.ext.asyncio import AsyncSession, async_sessionmaker, create_async_engine
+from sqlalchemy.ext.asyncio import (AsyncSession, async_sessionmaker,
+                                    create_async_engine)
 from sqlalchemy.orm import declarative_base, sessionmaker
 
 from ..core.exception import exception_to_dict
@@ -121,40 +122,27 @@ class DatabaseInstance:
     def _build_async_url(self, db_url: str) -> str:
         if self.db_driver_sync:
             if self.db_driver_async:
-                db_url = (
-                    db_url
-                    .replace(
-                        f"{self.db_backend}+{self.db_driver_sync}://",
-                        f"{self.db_backend}+{self.db_driver_async}://",
-                        1
-                    )
+                db_url = db_url.replace(
+                    f"{self.db_backend}+{self.db_driver_sync}://",
+                    f"{self.db_backend}+{self.db_driver_async}://",
+                    1,
                 )
             else:
-                db_url = (
-                    db_url
-                    .replace(
-                        f"{self.db_backend}+{self.db_driver_sync}://",
-                        f"{self.db_backend}://",
-                        1
-                    )
+                db_url = db_url.replace(
+                    f"{self.db_backend}+{self.db_driver_sync}://",
+                    f"{self.db_backend}://",
+                    1,
                 )
         else:
             if self.db_driver_async:
-                db_url = (
-                    db_url
-                    .replace(
-                        f"{self.db_backend}://",
-                        f"{self.db_backend}+{self.db_driver_async}://",
-                        1
-                    )
+                db_url = db_url.replace(
+                    f"{self.db_backend}://",
+                    f"{self.db_backend}+{self.db_driver_async}://",
+                    1,
                 )
 
-
         if "postgresql" in db_url:
-            return (
-                db_url
-                .replace("sslmode=require", "ssl=require", 1)
-            )
+            return db_url.replace("sslmode=require", "ssl=require", 1)
         else:
             return db_url
 
