@@ -27,7 +27,9 @@ def filters_mapper(
             )
 
         values = []
-        db_values = list(map(lambda x: x[0], db.execute(union(*distinct_names_query)).fetchall()))
+        db_values = list(
+            map(lambda x: x[0], db.execute(union(*distinct_names_query)).fetchall())
+        )
         if columns_type == "select_array":
             for db_value in db_values:
                 if isinstance(db_value, list):
