@@ -4,6 +4,8 @@ from typing import AsyncGenerator, Generator
 
 import redis
 from redis.asyncio import Redis as AsyncRedis
+from redis.asyncio.connection import ConnectionPool as AsyncConnectionPool
+from redis.connection import ConnectionPool
 
 from .config import RedisConfig
 
@@ -15,6 +17,8 @@ class RedisInstance:
     def __init__(self, redis_config: RedisConfig):
         self.config = redis_config
         self.redis_url = self._set_redis_url()
+        self._sync_pool = None
+        self._async_pool = None
 
     def _set_redis_url(self) -> str:
         """Constructs the Redis connection URL."""
@@ -42,28 +46,46 @@ class RedisInstance:
         return f"{protocol}://{auth_part}{redis_host}:{redis_port}/{redis_db}"
 
     def get_redis_url(self) -> str:
+        """Returns the Redis connection URL."""
         return self.redis_url
 
+    def _get_sync_pool(self) -> ConnectionPool:
+        if not self._sync_pool:
+            self._sync_pool = ConnectionPool.from_url(
+                self.redis_url,
+                max_connections=self.config.get("redis_max_connections", 10),
+                socket_timeout=self.config.get("redis_socket_timeout", 5),
+            )
+        return self._sync_pool
+
+    def _get_async_pool(self) -> AsyncConnectionPool:
+        if not self._async_pool:
+            self._async_pool = AsyncConnectionPool.from_url(
+                self.redis_url,
+                max_connections=self.config.get("redis_max_connections", 10),
+                socket_timeout=self.config.get("redis_socket_timeout", 5),
+            )
+        return self._async_pool
+
     def get_redis_client(self) -> redis.Redis:
-        return redis.Redis.from_url(self.redis_url)
+        return redis.Redis(connection_pool=self._get_sync_pool())
 
     async def get_async_redis_client(self) -> AsyncRedis:
-        return AsyncRedis.from_url(self.redis_url)
+        return AsyncRedis(connection_pool=self._get_async_pool())
 
     @contextmanager
     def get_redis(self) -> Generator[redis.Redis, None, None]:
         """Context manager for synchronous Redis client."""
-        redis_client = self.get_redis_client()
+        client = self.get_redis_client()
         try:
-            yield redis_client
+            yield client
         finally:
-            redis_client.close()
+            pass
 
     @asynccontextmanager
     async def get_async_redis(self) -> AsyncGenerator[AsyncRedis, None]:
-        """Async context manager for Redis client."""
-        async_redis_client = await self.get_async_redis_client()
+        client = await self.get_async_redis_client()
         try:
-            yield async_redis_client
+            yield client
         finally:
-            await async_redis_client.aclose()
+            pass
