@@ -62,14 +62,38 @@ class Worker:
         self._discovered_task = task.get_tasks()
         return self
 
-    def set_redis(self, redis_instance: RedisInstance) -> "Worker":
-        """Configure Redis broker/backend and related SSL settings."""
+    def set_redis(
+            self,
+            redis_instance: RedisInstance,
+            retry_on_timeout: bool = True,
+            socket_keepalive: bool = True,
+    ) -> "Worker":
+        """
+        Configure Redis broker/backend and related SSL settings.
+
+        Parameters:
+            redis_instance (RedisInstance): The Redis instance to use for broker and backend.
+            retry_on_timeout (bool, optional): Whether to retry Redis operations on timeout. Defaults to True.
+            socket_keepalive (bool, optional): Whether to enable TCP keepalive on Redis sockets. Defaults to True.
+        """
         redis_url = redis_instance.get_redis_url()
         self._celery["broker"] = redis_url
         self._celery["backend"] = redis_url
         self._celery_conf["redbeat_redis_url"] = redis_url
         self._celery_conf["ONCE"]["settings"]["url"] = redis_url
 
+        redis_max_connections = redis_instance.config.get("redis_max_connections", 10)
+        redis_socket_connect_timeout = redis_instance.config.get("redis_socket_timeout", 10)
+        self._celery_conf["broker_transport_options"]["redis_max_connections"] = redis_max_connections
+        self._celery_conf["broker_transport_options"]["redis_socket_connect_timeout"] = redis_socket_connect_timeout
+        self._celery_conf["broker_transport_options"]["redis_retry_on_timeout"] = retry_on_timeout
+        self._celery_conf["broker_transport_options"]["redis_socket_keepalive"] = socket_keepalive
+
+        self._celery_conf["result_backend_transport_options"]["redis_max_connections"] = redis_max_connections
+        self._celery_conf["result_backend_transport_options"]["redis_socket_connect_timeout"] = redis_socket_connect_timeout
+        self._celery_conf["result_backend_transport_options"]["redis_retry_on_timeout"] = retry_on_timeout
+        self._celery_conf["result_backend_transport_options"]["redis_socket_keepalive"] = socket_keepalive
+
         if redis_url.startswith("rediss"):
             self._celery["broker_use_ssl"] = {"ssl_cert_reqs": ssl.CERT_NONE}
             self._celery["redis_backend_use_ssl"] = {"ssl_cert_reqs": ssl.CERT_NONE}
